@@ -7,13 +7,14 @@ class App::Gimei::Parser {
     use App::Gimei::Generator;
     use App::Gimei::Generators;
 
-    field $args : param;
+    #
+    # class methods
+    #
 
-    method parse () {
+    sub parse ($args) {
         my $generators = App::Gimei::Generators->new();
-
         foreach my $arg ( @{$args} ) {
-            $generators->add_generator( $self->parse_arg($arg) );
+            $generators->add_generator( _parse_arg($arg) );
         }
 
         return $generators;
@@ -22,16 +23,14 @@ class App::Gimei::Parser {
     # BNF-like notation
     #
     # ARG:          [WORD_TYPE] [':' RENDERING]
-    #
     # WORD_TYPE:　   TYPE_NAME [':' SUBTYPE_NAME] | TYPE_ADDRESS [':' SUBTYPE_ADDRESS ]
     # TYPE_NAME:       'name'       | 'male'     | 'female'
     # SUBTYPE_NAME:    'family'     | 'given'
     # TYPE_ADDRESS:    'address'
     # SUBTYPE_ADDRESS: 'prefecture' | 'city'     | 'town'
-    #
-    # RENDERING:    'kanji'      | 'hiragana' | 'katakana' | 'romaji'
+    # RENDERING:       'kanji'      | 'hiragana' | 'katakana' | 'romaji'
     # (DO NOT support romaji rendering for type address)
-    method parse_arg ($arg) {
+    sub _parse_arg ($arg) {
         my ( $gen, @tokens, %params );
 
         @tokens = split( /[-:]/, $arg );
@@ -42,15 +41,15 @@ class App::Gimei::Parser {
             if ( $token ne 'name' ) {
                 $params{gender} = $token;
             }
-            $params{word_subtype} = $self->subtype_name( \@tokens );
+            $params{word_subtype} = _subtype_name( \@tokens );
         } elsif ( $token eq 'address' ) {    # TYPE_ADDRESS
             $params{word_class}   = "Data::Gimei::Address";
-            $params{word_subtype} = $self->subtype_address( \@tokens );
+            $params{word_subtype} = _subtype_address( \@tokens );
         } else {
             die "Error: unknown word_type: $token\n";
         }
 
-        $params{rendering} = $self->rendering( \@tokens );
+        $params{rendering} = _rendering( \@tokens );
 
         if (@tokens) {
             if ( defined $params{word_subtype} ) {
@@ -63,7 +62,7 @@ class App::Gimei::Parser {
         return App::Gimei::Generator->new(%params);
     }
 
-    method subtype_name ($tokens_ref) {
+    sub _subtype_name ($tokens_ref) {
         my $word_subtype;
 
         my %map = (
@@ -83,7 +82,7 @@ class App::Gimei::Parser {
         return $word_subtype;
     }
 
-    method subtype_address ($tokens_ref) {
+    sub _subtype_address ($tokens_ref) {
         my ($word_subtype);
 
         my $token = @$tokens_ref[0] // '';
@@ -95,7 +94,7 @@ class App::Gimei::Parser {
         return $word_subtype;
     }
 
-    method rendering ($tokens_ref) {
+    sub _rendering ($tokens_ref) {
         my $rendering = 'kanji';
 
         my $token = @$tokens_ref[0] // '';
